# frozen_string_literal: true

require 'cht-chaphql'
require 'cht-chaphql/graphql_formatters'

SAVINGS_MANAGEMENT_FMTRS =
  YAML.load_file(File.join(__dir__, '../helpers/formatters.yml'))

# module for savings-management
module ChtApitestSavingsManagement
  include Chaphql
  include Chaphql::GraphQLHelpers

  # module for your shortcuts
  module SavingsManagementHelpers
    def via_public
      %w[staging canary preprod prod].include?(getenv)
    end

    def auth_service
      LocalAuthService.new(via_public: via_public)
      #LocalAuthService.new()
    end
    # insertion point for shortcuts

    def run_savings_management_jobs(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('run_savings_management_jobs')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"customers"=>args[:customers], "jobType"=>args[:jobType]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_usage_based_discount_opportunities_summary(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_usage_based_discount_opportunities_summary')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"usageBasedDiscountOpportunitiesRequest"=>args[:usageBasedDiscountOpportunitiesRequest]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_spend_based_discount_opportunities_summary(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_spend_based_discount_opportunities_summary')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"discountSummaryRequest"=>args[:discountSummaryRequest]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_unified_effective_savings_rate_summary(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_unified_effective_savings_rate_summary')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"filterInput"=>args[:filterInput]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_discount_configuration_summary(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_discount_configuration_summary')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"providers"=>args[:providers]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_expiring_commitments_summary(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_expiring_commitments_summary')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"commitmentType"=>args[:commitmentType], "requestInput"=>{"filterInput"=>args[:filterInput]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_usage_based_discount_opportunities(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_usage_based_discount_opportunities')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"usageBasedDiscountOpportunitiesRequest"=>args[:usageBasedDiscountOpportunitiesRequest]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_spend_based_discount_opportunities(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_spend_based_discount_opportunities')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"discountSummaryRequest"=>args[:discountSummaryRequest]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def query_effective_savings_rate_data(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('query_effective_savings_rate_data')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {"requestInput"=>{"filterInput"=>args[:filterInput]}}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    def _service(args = {})
      args[:service] = SavingsManagementService.new
      sym = first_no_cap(camelize('_service')).to_sym
      headers = apitest_headers(
        args.merge(with_auth: true,
        auth_service: auth_service))
      data = args[:body] || format_request(sym, args)
      variables = {}
      graphql url(args), data, variables, headers, args
      expect_success_graphql
      check(sym, args) unless args[:body]
      json_body[:data][sym]
    end

    # end of shortcut insertion
  end

  # class for your service
  class SavingsManagementService < ChtNgService
    include RSpec::Matchers

    SAVINGS_MANAGEMENT_DEFAULTS = {
      name: 'SavingsManagement',
      default_namespace: 'savings-management',
      service_name: 'savings-management',
      pr_parent: 'savings-management',
      formatters: SAVINGS_MANAGEMENT_FMTRS['formatters'],
      v2_checkers: SAVINGS_MANAGEMENT_FMTRS['v2_checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(SAVINGS_MANAGEMENT_DEFAULTS))
    end
  end

  # class for api-proxy support of savings-management service
  class ApiProxySavingsManagement < ChtNgService
    include RSpec::Matchers

    API_PROXY_DEFAULTS = {
      name: 'ApiProxySavingsManagement',
      default_namespace: 'api-proxy',
      service_name: 'api-proxy',
      pr_parent: 'api-proxy',
      formatters: SAVINGS_MANAGEMENT_FMTRS['formatters'],
      v2_checkers: SAVINGS_MANAGEMENT_FMTRS['v2_checkers']
    }.freeze
    def initialize(args = {})
      super(args.merge(API_PROXY_DEFAULTS))
    end
  end
end
