require 'spec_helper'

module SavingsManagementTest
  describe 'SavingsManagement queryDiscountOpportunitiesSummary' do
    include_context 'request metadata'

    it 'Spend based discount opportunities summary' do
      wrap_request do
        variables = {
          "requestInput": {
            "discountSummaryRequest": [
              {
                "billingAccountId": [""],
                "commitmentDuration": "ONE_YEAR",
                "provider": "AWS",
                "purchaseOption": "ALL_UPFRONT"
              }
            ]
          }
        }
        graphql url(service: service),
                format_request(
                  :querySpendBasedDiscountOpportunitiesSummary,
                  service: service
                ),
                variables, headers
        expect_success_graphql
        check(:querySpendBasedDiscountOpportunitiesSummary, service: service)
      end
    end


    it 'Usage based discount opportunities summary' do
      wrap_request do
        variables = {
            "requestInput": {
              "usageBasedDiscountOpportunitiesRequest": {
              "billingAccountId": [],
              "commitmentDuration": "THREE_YEAR",
              "provider": "AWS",
              "purchaseOption": "ALL_UPFRONT",
              "region": "null",
              "serviceType": ""
            }
          }
        }
        graphql url(service: service),
                format_request(
                  :queryUsageBasedDiscountOpportunitiesSummary,
                  service: service
                ),
                variables, headers
        expect_success_graphql
        check(:queryUsageBasedDiscountOpportunitiesSummary, service: service)
      end
    end

    # This case should fail as Azure doesn't have Savings plan
    it 'Spend based discount opportunities summary For Azure' do
      wrap_request do
        variables = {
          "requestInput": {
            "discountSummaryRequest": [
              {
                "billingAccountId": [""],
                "commitmentDuration": "ONE_YEAR",
                "provider": "AZURE",
                "purchaseOption": "ALL_UPFRONT"
              }
            ]
          }
        }
        graphql url(service: service),
                format_request(
                  :querySpendBasedDiscountOpportunitiesSummary,
                  service: service
                ),
                variables, headers
        expect_success_graphql
        check(:querySpendBasedDiscountOpportunitiesSummary, service: service)
      end
    end

    it 'Usage based discount opportunities summary For Azure' do
      wrap_request do
        variables = {
            "requestInput": {
              "usageBasedDiscountOpportunitiesRequest": {
              "billingAccountId": [],
              "commitmentDuration": "ONE_YEAR",
              "provider": "AZURE",
              "purchaseOption": "ALL_UPFRONT",
              "region": "null",
              "serviceType": ""
            }
          }
        }
        graphql url(service: service),
                format_request(
                  :queryUsageBasedDiscountOpportunitiesSummary,
                  service: service
                ),
                variables, headers
        expect_success_graphql
        check(:queryUsageBasedDiscountOpportunitiesSummary, service: service)
      end
    end


  end
end
